==> jc-1.4.0.tar.gz: ppg/atoms/GrammarPart.h <==
// public abstract class ppg.atoms.GrammarPart

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_atoms_GrammarPart_H_
#define _JC_ppg_atoms_GrammarPart_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_ppg_atoms_GrammarPart$sub_refs	_jc_ppg_atoms_GrammarPart$sub_refs;
typedef struct _jc_ppg_atoms_GrammarPart$sub_nonrefs	_jc_ppg_atoms_GrammarPart$sub_nonrefs;
typedef struct _jc_ppg_atoms_GrammarPart$refs	_jc_ppg_atoms_GrammarPart$refs;
typedef struct _jc_ppg_atoms_GrammarPart$nonrefs	_jc_ppg_atoms_GrammarPart$nonrefs;
typedef struct _jc_ppg_atoms_GrammarPart$object	_jc_ppg_atoms_GrammarPart$object;

typedef const struct _jc_ppg_atoms_GrammarPart$vmethods	_jc_ppg_atoms_GrammarPart$vmethods;
typedef const struct _jc_ppg_atoms_GrammarPart$vtable	_jc_ppg_atoms_GrammarPart$vtable;
typedef const struct _jc_ppg_atoms_GrammarPart$vtype	_jc_ppg_atoms_GrammarPart$vtype;

// Constructors
extern void _jc_ppg_atoms_GrammarPart$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_atoms_GrammarPart$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_GrammarPart$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_GrammarPart$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_ppg_atoms_GrammarPart$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_GrammarPart$object *);
};

// Vtable
struct _jc_ppg_atoms_GrammarPart$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
};

// Vtype
struct _jc_ppg_atoms_GrammarPart$vtype {
	_jc_type			type;
	_jc_ppg_atoms_GrammarPart$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_GrammarPart$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_atoms_GrammarPart$refs {
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_GrammarPart$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_GrammarPart$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
};

// Object instance structure
struct _jc_ppg_atoms_GrammarPart$object {
	_jc_ppg_atoms_GrammarPart$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_GrammarPart$vtype	*vtype;
	_jc_ppg_atoms_GrammarPart$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_GrammarPart$vtype _jc_ppg_atoms_GrammarPart$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_GrammarPart, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_GrammarPart$class_object;

#endif	/* _JC_ppg_atoms_GrammarPart_H_ */

==> jc-1.4.6.tar.gz: ppg/atoms/GrammarPart.h <==
// public abstract class ppg.atoms.GrammarPart

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_atoms_GrammarPart_H_
#define _JC_ppg_atoms_GrammarPart_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_ppg_atoms_GrammarPart$sub_refs	_jc_ppg_atoms_GrammarPart$sub_refs;
typedef struct _jc_ppg_atoms_GrammarPart$sub_nonrefs	_jc_ppg_atoms_GrammarPart$sub_nonrefs;
typedef struct _jc_ppg_atoms_GrammarPart$refs	_jc_ppg_atoms_GrammarPart$refs;
typedef struct _jc_ppg_atoms_GrammarPart$nonrefs	_jc_ppg_atoms_GrammarPart$nonrefs;
typedef struct _jc_ppg_atoms_GrammarPart$object	_jc_ppg_atoms_GrammarPart$object;

typedef const struct _jc_ppg_atoms_GrammarPart$vmethods	_jc_ppg_atoms_GrammarPart$vmethods;
typedef const struct _jc_ppg_atoms_GrammarPart$vtable	_jc_ppg_atoms_GrammarPart$vtable;
typedef const struct _jc_ppg_atoms_GrammarPart$vtype	_jc_ppg_atoms_GrammarPart$vtype;

// Constructors
extern void _jc_ppg_atoms_GrammarPart$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_atoms_GrammarPart$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_GrammarPart$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_GrammarPart$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_GrammarPart$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_ppg_atoms_GrammarPart$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_GrammarPart$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_atoms_GrammarPart$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
};

// Vtype
struct _jc_ppg_atoms_GrammarPart$vtype {
	_jc_type			type;
	_jc_ppg_atoms_GrammarPart$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_GrammarPart$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_atoms_GrammarPart$refs {
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_GrammarPart$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_GrammarPart$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
};

// Object instance structure
struct _jc_ppg_atoms_GrammarPart$object {
	_jc_ppg_atoms_GrammarPart$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_GrammarPart$vtype	*vtype;
	_jc_ppg_atoms_GrammarPart$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_GrammarPart$vtype _jc_ppg_atoms_GrammarPart$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_GrammarPart, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_GrammarPart$class_object;

#endif	/* _JC_ppg_atoms_GrammarPart_H_ */
